@@ -3,7 +3,7 @@ package Net::FullAuto::ISets::Amazon::KaliLinux_is;
 ### OPEN SOURCE LICENSE - GNU AFFERO PUBLIC LICENSE Version 3.0 #######
 #
 #    Net::FullAuto - Powerful Network Process Automation Software
-#    Copyright © 2000-2015  Brian M. Kelly
+#    Copyright © 2000-2016  Brian M. Kelly
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as
@@ -46,9 +46,9 @@ my $install_dashboard_on_kalilinux=sub {
    my $server_host_block=$_[2]||'';
    my $handle=$main::aws->{$server_type}->[$cnt]->[1];
    my ($stdout,$stderr,$hash,$error,$output)=('','','','',''); 
-   ($stdout,$stderr)=$handle->cmd("apt-get update",'__display__');
+   ($stdout,$stderr)=$handle->cmd("apt-get update",3600,'__display__');
    ($stdout,$stderr)=$handle->cmd(
-       "apt-get -o Dpkg::Progress=true -y install apache2",
+       "apt-get -o Dpkg::Progress=true -y install apache2",3600,
        '__display__');
    ($stdout,$stderr)=$handle->cmd("sed -e 's/index.php //' ".
         "/etc/apache2/mods-enabled/dir.conf");
@@ -56,14 +56,19 @@ my $install_dashboard_on_kalilinux=sub {
         "/etc/apache2/mods-enabled/dir.conf");
    ($stdout,$stderr)=$handle->cmd("service apache2 restart");
    ($stdout,$stderr)=$handle->cmd(
-      "apt-get -o Dpkg::Progress=true -y install git",'__display__');
+      "apt-get -o Dpkg::Progress=true -y install git",3600,'__display__');
+   if ($stderr) {
+      print "Kali Linux Instruction Set aws cmd ERROR!: $stderr at Line",
+         __LINE__,"\n";
+      Net::FullAuto::FA_Core::cleanup();
+   }
    ($stdout,$stderr)=$handle->cwd("/var/www");
    ($stdout,$stderr)=$handle->cmd("git clone ".
        "https://github.com/afaqurk/linux-dash.git 2>&1",
        '__display__');
    ($stdout,$stderr)=$handle->cmd(
        "apt-get -o Dpkg::Progress=true -y install php5 ".
-       "libapache2-mod-php5 php5-mcrypt",
+       "libapache2-mod-php5 php5-mcrypt",3600,
        '__display__');
    ($stdout,$stderr)=$handle->cmd("/usr/sbin/apache2ctl start",
       '__allow_no_output__');
@@ -88,7 +93,7 @@ my $install_dashboard_on_kalilinux=sub {
           |_| \_|\___|\__|     |_|   \__,_|_|_/_/   \_\__,_|\__\___/ ©
 
 
-   Copyright © 2000-2015  Brian M. Kelly  Brian.Kelly@FullAuto.com
+   Copyright © 2000-2016  Brian M. Kelly  Brian.Kelly@FullAuto.com
 
 END
    eval {
@@ -115,7 +120,12 @@ my $configure_kalilinux=sub {
    ($stdout,$stderr)=$handle->cmd("sudo apt update",'__display__');
    ($stdout,$stderr)=$handle->cmd(
        "sudo apt-get -o Dpkg::Progress=true -y install git debootstrap",
-       '__display__');
+       3600,'__display__');
+   if ($stderr) {
+      print "Kali Linux Instruction Set cmd ERROR!: $stderr at Line".
+         __LINE__."\n";
+      Net::FullAuto::FA_Core::cleanup();
+   }
    ($stdout,$stderr)=$handle->cmd("sudo ln -sf ".
        "/usr/share/debootstrap/scripts/{wheezy,kali}");
    # BUILDING uses Jazmine Figlet Font
@@ -145,9 +155,14 @@ my $configure_kalilinux=sub {
    (The Kali Linux™ Project is **NOT** a sponsor of the FullAuto© Project.)
 END
    print $install_kali;sleep 10;
-   ($stdout,$stderr)=$handle->cmd(
-      "git clone https://github.com/offensive-security/kali-cloud-build.git",
-      '__display__');
+   ($stdout,$stderr)=$handle->cmd('git clone '.
+      "https://github.com/offensive-security/kali-cloud-build.git 2>&1",
+      3600,'__display__');
+   if ($stderr) {
+      print "Kali Linux Instruction Set cmd ERROR!: $stderr at Line".
+         __LINE__."\n";
+      Net::FullAuto::FA_Core::cleanup();
+   }
    ($stdout,$stderr)=$handle->cwd("kali-cloud-build");
    my $sk='';my $ak='';
    unless (exists $main::aws->{access_id}) {
@@ -188,7 +203,7 @@ END
          }
          ($hash,$output,$error)=run_aws_cmd(
             "aws ec2 delete-snapshot --snapshot-id ".
-            $image->{BlockDeviceMappings}->{Ebs}->{SnapshotId});
+            $image->{BlockDeviceMappings}->[0]->{Ebs}->{SnapshotId});
          if ($error) {
             print "Kali Linux Instruction Set aws cmd ERROR!: $error at Line".
                __LINE__."\n";
